@@ -21,70 +21,32 @@
 #FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 #OTHER DEALINGS IN THE SOFTWARE.
 
-class Configuration:
+import os
+
+class Configuration(object):
 
     def __init__(self):
-        self._version = '8.13'
-        self._reportGroup = 'Default Report Group'
-        self._url = "Sandbox"
-        self._proxy = None
-        self._timeout = 65
-        self._printXml = False
-        
-    def getUser(self):
-        return self._user
-        
-    def setUser(self, user):
-        self._user = user
-        
-    def getMerchantId(self):
-        return self._merchantId
-        
-    def setMerchantId(self, merchantId):
-        self._merchantId = merchantId
-        
-    def getPassword(self):
-        return self._password
-        
-    def setPassword(self, password):
-        self._password = password
-    
-    def getVersion(self):
-        return self._version
-        
-    def setVersion(self, version):
-        self._version = version
-    
-    def getReportGroup(self):
-        return self._reportGroup
-        
-    def setReportGroup(self, reportGroup):
-        self._reportGroup = reportGroup
-        
-    def getUrl(self):
+        self.version = 8.25
+        self.reportGroup = 'Default Report Group'
+        self._url = 'Sandbox'
+        self.proxy = None
+        self.timeout = 65
+        self.printXml = False
+        self.configFolder = os.environ['LITLE_SDK_CONFIG']\
+            if 'LITLE_SDK_CONFIG' in os.environ else os.path.expanduser('~')
+        self.__LITLE_SDK_CONFIG = '.litle_Python_SDK_config'
+
+    @property
+    def url(self):
         return self._urlMapper(self._url)
-        
-    def setUrl(self, url):
-        self._url = url
-        
-    def getProxy(self):
-        return self._proxy
-        
-    def setProxy(self, proxy):
-        self._proxy = proxy
-        
-    def getTimeout(self):
-        return self._timeout
-        
-    def setTimeout(self, timeout):
-        self._timeout = timeout
-        
-    def getPrintXml(self):
-        return self._printXml
-    
-    def setPrintXml(self, printXml):
-        self._printXml = printXml
-        
+
+    @url.setter
+    def url(self, value):
+        self._url = value
+
+    def getConfigFileName(self):
+        return self.__LITLE_SDK_CONFIG
+
     def _urlMapper(self,target):
         if (target == "Cert"):
             return 'https://cert.litle.com/vap/communicator/online'
